@@ -1,8 +1,7 @@
-import json
 import re
 from datetime import datetime, timedelta
-from urllib import parse
 from pathlib import Path
+from urllib import parse
 
 import requests
 from requests_ntlm import HttpNtlmAuth
@@ -45,7 +44,7 @@ class SharePointSession(requests.Session):
         self._redigest()
 
     def _redigest(self):
-        """"Check and refresh site's request form digest"""
+        """ "Check and refresh site's request form digest"""
 
         if self.expire <= datetime.now():
             # print("=> Requesting form digest value...")
@@ -86,7 +85,7 @@ class SharePointSession(requests.Session):
         """Make POST request and include x-requestdigest header"""
         # print(f"=> POST: {url}")
         if "headers" in kwargs.keys():
-             kwargs["headers"].update(**kwargs["headers"])
+            kwargs["headers"].update(**kwargs["headers"])
         # self.headers.update({"Authorization": "Bearer " + self._redigest()})
         self.headers.update({"x-requestdigest": self._redigest()})
         return super().post(url, *args, **kwargs)
@@ -122,9 +121,7 @@ class SharePointSession(requests.Session):
         """Get lists."""
         return self.get(weblist_url, **kwargs)
 
-    def get_list_metadata(
-        self, weblist_url, list_guid=None, list_title=None, **kwargs
-    ):
+    def get_list_metadata(self, weblist_url, list_guid=None, list_title=None, **kwargs):
         """Get list metadata."""
         if list_guid is None and list_title is None:
             raise ValueError("Either `list_guid` or `list_title` must be set.")
@@ -229,12 +226,17 @@ class SharePointSession(requests.Session):
         self,
         weblist_url,
         item_id,
+        content,
         filename,
         list_guid=None,
         list_title=None,
         headers={},
     ):
-        """Upload a file to a list item."""
+        """
+        Upload a file to a list item. content is the content of the file.
+            with open(filename, "rb") as fp:
+                content = fp.read()
+        """
         if list_guid is None and list_title is None:
             raise ValueError("Either `list_guid` or `list_title` must be set.")
         if list_guid and list_title:
@@ -242,22 +244,18 @@ class SharePointSession(requests.Session):
                 "Either `list_guid` or `list_title` must be set, not both."
             )
 
-        uploaded_filename = Path(filename).name
         if list_guid:
             url = (
                 f"{weblist_url}(guid'{list_guid}')/items({item_id})"
-                f"/AttachmentFiles/add(FileName='{uploaded_filename}')"
+                f"/AttachmentFiles/add(FileName='{filename}')"
             )
         else:
             list_title = parse.quote(list_title)
             url = (
                 f"{weblist_url}/getbytitle('{list_title}')/items({item_id})"
-                f"/AttachmentFiles/add(FileName='{uploaded_filename}')"
+                f"/AttachmentFiles/add(FileName='{filename}')"
             )
-            print(url)
-        # Perform the actual upload
-        with open(filename, "rb") as fp:
-            content = fp.read()
+            # print(url)
 
         # Add the content-length
         headers.update({"content-length": str(len(content))})
